<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use App\Models\Constituency;
use App\Models\County;
use Illuminate\Support\Facades\Auth;

class ConstituencyController extends Controller
{

    const CONSTITUENCIES_BLADE = 'src/constituencies';
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $constituencies = Constituency::all();
        $counties = County::all();
        return view(ConstituencyController::CONSTITUENCIES_BLADE,
        ['constituencies' => $constituencies, 'counties' => $counties,
         'selectedConstituency' => null]);
    }

    public function save(Request $request){

        $data = $request->validate([
            'constituency_name' => 'required|max:255',
            'constituency_code' => 'required|max:255',
            'county_id' => 'required'
        ]);

        $data['created_by'] = Auth::user()->user_id;
    
        $selected = $request->selected_constituency;
    
        if($selected){
            $constituency = tap(Constituency::where('constituency_id', 
            $selected)->update($data));
        }else {
            $constituency = tap(new Constituency($data))->save();
        }
        return redirect('/constituencies');
    }

    public function search(Request $request){

        $keyword = $request->keyword;
        $constituencies = DB::select(Db::raw("select * from constituency inner join county  
            on county.county_id = constituency.county_id where constituency_name
             like '%".$keyword."%' or county_name like '%".$keyword."%'"));
        return json_encode($constituencies);
    }

    public function edit($id) {
        
        $constituencyId = $id;
        $selectedConstituency = Constituency::find($constituencyId);
        $constituencies = Constituency::all();
        $counties = County::all();
        return view(ConstituencyController::CONSTITUENCIES_BLADE, 
        ['constituencies' => $constituencies, 'counties' => $counties,
        'selectedConstituency' => $selectedConstituency]);
    }

    public function del(Request $request) {

        $constituencyId = $request->deleteconstituency;
        $constituency = Constituency::find($constituencyId);
        $constituency->delete();
        $constituencies = Constituency::all();
        $counties = County::all();
        return view(ConstituencyController::CONSTITUENCIES_BLADE, 
        ['constituencies' => $constituencies, 'counties' => $counties, 
        'selectedConstituency' => null]);
    }
}