<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use App\Models\CountyAssembly;
use App\Models\County;
use Illuminate\Support\Facades\Auth;

class CountyAssemblyController extends Controller
{

    const ASSEMBLIES_BLADE = 'src/county_assemblies';
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $countyassemblies = CountyAssembly::all();
        $counties = County::all();

        return view(CountyAssemblyController::ASSEMBLIES_BLADE,
            ['countyassemblies' => $countyassemblies, 'counties' => $counties,
            'selectedCountyassembly' => null]);
    }

    public function save(Request $request){

        $data = $request->validate([
            'county_assembly_name' => 'required|max:255',
            'county_assembly_code' => 'required|max:255',
            'county_id' => 'required'
        ]);

        $data['created_by'] = Auth::user()->user_id;
    
        $selected = $request->selected_countyassembly;
    
        if($selected){
            $countyAssembly = tap(CountyAssembly::where('county_assembly_id', 
            $selected)->update($data));
        }else {
            $countyAssembly = tap(new CountyAssembly($data))->save();
        }

        return redirect('/countyassemblies');
    }

    public function search(Request $request){

        $keyword = $request->keyword;
        $countyassemblies = DB::select(Db::raw("select * from county_assembly
         inner join county on county.county_id = county_assembly.county_id
          where county_assembly_name like '%".$keyword."%' or 
          county_name like '%".$keyword."%'"));

        return json_encode($countyassemblies);
    }

    public function edit($id) {
        
        $countyAssemblyId = $id;
        $selectedCountyassembly = CountyAssembly::find($countyAssemblyId);
        $countyassemblies = CountyAssembly::all();
        $counties = County::all();

        return view(CountyAssemblyController::ASSEMBLIES_BLADE, 
            ['countyassemblies' => $countyassemblies, 'counties' => $counties,
            'selectedCountyassembly' => $selectedCountyassembly]);
    }

    public function del(Request $request) {

        $countyAssemblyId = $request->deletecountyassembly;
        $countyassembly = CountyAssembly::find($countyAssemblyId);
        $countyassembly->delete();
        $countyassemblies = CountyAssembly::all();
        $counties = County::all();

        return view(CountyAssemblyController::ASSEMBLIES_BLADE, 
            ['countyassemblies' => $countyassemblies, 'counties' => $counties, 
            'selectedCountyassembly' => null]);
    }
}