<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use App\Models\County;
use Illuminate\Support\Facades\Auth;

class CountyController extends Controller
{

    const COUNTIES_BLADE = 'src/counties';
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $counties = County::all();
        return view(CountyController::COUNTIES_BLADE, 
        ['counties' => $counties, 'selectedCounty' => null]);
    }

    public function save(Request $request){

        $data = $request->validate([
            'county_name' => 'required|max:255',
            'county_code' => 'numeric|nullable',
        ]);

        $data['created_by'] = Auth::user()->user_id;
    
        $selected = $request->selected_county;
    
        if($selected){
            $county = tap(County::where('county_id', $selected)->update($data));
        }else {
            $county = tap(new County($data))->save();
        }
        return redirect('/counties');
    }

    public function search(Request $request){

        $counties = County::where('county_name', 'like', 
        '%' .$request->keyword. '%')->orWhere('county_code', 'like', 
        '%' .$request->keyword. '%')->get();
        return json_encode($counties);
    }

    public function edit($id) {
        $countyId = $id;
        $selectedCounty = County::find($countyId);
        $counties = County::all();
        return view(CountyController::COUNTIES_BLADE, 
        ['counties' => $counties, 'selectedCounty' => $selectedCounty]);
    }

    public function del(Request $request) {

        $countyId = $request->deletecounty;
        $county = County::find($countyId);
        $county->delete();
        $counties = County::all();
        return view(CountyController::COUNTIES_BLADE, 
        ['counties' => $counties, 'selectedCounty' => null]);
    }
}