<?php

namespace App\Http\Controllers;

use App\Models\QuestionnairePart;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use Illuminate\Support\Facades\Auth;

class QuestionnairePartController extends Controller
{

    const PARTS_BLADE = 'src/questionnaire_parts';
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $questionnaireparts = QuestionnairePart::all();

        return view(QuestionnairePartController::PARTS_BLADE, 
                ['questionnaireparts' => $questionnaireparts,
                 'selectedQuestionnairePart' => null]);
    }


    /**
     * Search for selected user roles.
     *
     * @return \Illuminate\Http\Response
     */
    public function search(Request $request){

        $keyword = $request->keyword;
        $questionnaireparts = DB::select(Db::raw("select * from questionnaire_part
         where part_name like '%".$keyword."%'"));

        return json_encode($questionnaireparts);
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function save(Request $request)
    {
        $data = $request->validate([
            'part_name' => 'required|max:255'
        ]);
    
        $data['created_by'] = Auth::user()->user_id;

        $selected = $request->selected_questionnairepart;
    
        if($selected){
            $questionnairepart = tap(QuestionnairePart::where('questionnaire_part_id',
             $selected)->update($data));
        }else {
            $questionnairepart = tap(new QuestionnairePart($data))->save();
        }
        return redirect('/questionnaireparts');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\UserRole  $userRole
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $questionnairePartId = $id;
        $selectedQuestionnairePart = QuestionnairePart::find($questionnairePartId);
        $questionnaireparts = QuestionnairePart::all();

        return view(QuestionnairePartController::PARTS_BLADE, 
            ['questionnaireparts' => $questionnaireparts, 
            'selectedQuestionnairePart' => $selectedQuestionnairePart]);
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\UserRole  $userRole
     * @return \Illuminate\Http\Response
     */
    public function del(Request $request)
    {
        $questionnairePartId = $request->deletequestionnairepart;
        $questionnairepart = QuestionnairePart::find($questionnairePartId);
        $questionnairepart->delete();

        return redirect('/questionnaireparts');
    }
}