<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use App\Models\SrcCircular;
use Illuminate\Support\Facades\Auth;

class SrcCircularController extends Controller
{

    const CIRCULAR_BLADE = 'src/src_circular';
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $circulars = SrcCircular::all();

        return view(SrcCircularController::CIRCULAR_BLADE, 
        ['circulars' => $circulars, 'selectedCircular' => null]);
    }

    public function save(Request $request){

        $data = $request->validate([
            'subject' => 'required|max:255',
            'ref_no' => 'required|max:255',
            'date_issued' => 'required|max:255'
        ]);

        $data['created_by'] = Auth::user()->user_id;
    
        $selected = $request->selected_circular;
    
        if($selected){
            tap(SrcCircular::where('src_circular_id', 
                $selected)->update($data));
        }else {
            tap(new SrcCircular($data))->save();
        }

        return redirect('/circulars');
    }

    public function search(Request $request){

        $circulars = SrcCircular::where('subject', 'like', 
        '%' .$request->keyword. '%')->orWhere('ref_no', 'like', 
        '%' .$request->keyword. '%')->orWhere('date_issued', 'like', 
        '%' .$request->keyword. '%')->get();

        return json_encode($circulars);
    }

    public function edit($id) {

        $srcCircularId = $id;
        $selectedCircular = SrcCircular::find($srcCircularId);
        $circulars = SrcCircular::all();

        return view(SrcCircularController::CIRCULAR_BLADE, 
            ['circulars' => $circulars, 'selectedCircular' => $selectedCircular]);
    }

    public function del(Request $request) {

        $srcCircularId = $request->deletecircular;
        $circular = SrcCircular::find($srcCircularId);
        $circular->delete();

        return redirect('/circulars');
    }
}