<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use App\Models\SubCategory;
use App\Models\Category;
use Illuminate\Support\Facades\Auth;

class SubCategoryController extends Controller
{

    const SUBCATEGORIES_BLADE = 'src/sub_categories';
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $subcategories = SubCategory::all();
        $categories = Category::all();
        return view(SubCategoryController::SUBCATEGORIES_BLADE,
        ['subcategories' => $subcategories, 'categories' => $categories,
         'selectedSubcategory' => null]);
    }

    public function save(Request $request){

        $data = $request->validate([
            'sub_category_name' => 'required|max:255',
            'category_id' => 'required'
        ]);

        $data['created_by'] = Auth::user()->user_id;
        $data['description'] = $request->description;
    
        $selected = $request->selected_subcategory;
    
        if($selected){
            $subcategory = tap(SubCategory::where('sub_category_id', 
            $selected)->update($data));
        }else {
            $subcategory = tap(new SubCategory($data))->save();
        }
        return redirect('/subcategories');
    }

    public function search(Request $request){

        $keyword = $request->keyword;
        $subcategories = DB::select(Db::raw("select * from sub_category inner join category  
            on category.category_id = sub_category.category_id where sub_category_name
             like '%".$keyword."%' or category_name like '%".$keyword."%'"));
        return json_encode($subcategories);
    }

    public function edit($id) {
        
        $subCategoryId = $id;
        $selectedSubcategory = SubCategory::find($subCategoryId);
        $subcategories = SubCategory::all();
        $categories = Category::all();
        return view(SubCategoryController::SUBCATEGORIES_BLADE, 
        ['subcategories' => $subcategories, 'categories' => $categories,
        'selectedSubcategory' => $selectedSubcategory]);
    }

    public function del(Request $request) {

        $subCategoryId = $request->deletesubcategory;
        $subcategory = SubCategory::find($subCategoryId);
        $subcategory->delete();

        return redirect('/subcategories');
    }
}