<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use App\Models\QuestionnaireTable;
use App\Models\SubQuestionnaire;
use Illuminate\Support\Facades\Auth;

class SubQuestionnaireController extends Controller
{

    const SUB_QUESTIONNAIRE_URL = 'questionnaire/view/';
    const SUB_SUB_QUESTIONNAIRE_URL = 'subquestionnaire/view/';
    const SUB_SUB_QUESTIONNAIRE_BLADE = 'src/sub_sub_questionnaire'; 

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function save(Request $request){

        $data = $request->validate([
            'sub_question' => 'required',
            'sub_question_no' => 'required',
            'questionnaire_id' => 'required'
        ]);

        $checkbox_options = null;
        $dropdown_options = null;

        $data['created_by'] = Auth::user()->user_id;
        $data['feedback_area'] = $request->sub_feedback;

        $include_checkbox_options = $request->sub_include_checkbox_options;
        
        if($include_checkbox_options == "1"){

            $checkbox_options = $request->sub_checkbox_options;
        }


        $data['checkbox_options'] = $checkbox_options;
        $include_dropdown_options = $request->sub_include_dropdown_options;
        
        if($include_dropdown_options == "1"){

            $dropdown_options = $request->sub_dropdown_options;
        }

        $data['dropdown_options'] = $dropdown_options;
        $data['needs_upload'] = $request->needs_upload;

        $subquestionnaire = tap(new SubQuestionnaire($data))->save();

        $include_answers_table  = $request->sub_include_answers_table;

        if($include_answers_table == "1") {

            $sub_questionnaire_id = $subquestionnaire->questionnaire_id;
            $table_no = $request->sub_table_no;
            $table_title = $request->sub_table_title;
            $table_html = $request->sub_table_html;
            $table_js = $request->sub_table_js;

            $tableData = ['sub_questionnaire_id' => $sub_questionnaire_id,
                          'table_no' => $table_no,
                          'table_title' => $table_title,
                          'table_html' => $table_html,
                          'table_js' => $table_js
                        ];
            tap(new QuestionnaireTable($tableData))->save();
        }

        return redirect(SubQuestionnaireController::SUB_QUESTIONNAIRE_URL.$request->questionnaire_id);
    }

    public function save_sub(Request $request){

        $data = $request->validate([
            'sub_question' => 'required',
            'sub_question_no' => 'required',
            'parent_sub_questionnaire_id' => 'required'
        ]);

        $checkbox_options = null;
        $dropdown_options = null;

        $data['created_by'] = Auth::user()->user_id;
        $data['feedback_area'] = $request->sub_feedback;

        $include_checkbox_options = $request->sub_include_checkbox_options;
        
        if($include_checkbox_options == "1"){

            $checkbox_options = $request->sub_checkbox_options;
        }


        $data['checkbox_options'] = $checkbox_options;
        $include_dropdown_options = $request->sub_include_dropdown_options;
        
        if($include_dropdown_options == "1"){

            $dropdown_options = $request->sub_dropdown_options;
        }

        $data['dropdown_options'] = $dropdown_options;
        $data['needs_upload'] = $request->needs_upload;

        $subquestionnaire = tap(new SubQuestionnaire($data))->save();

        $include_answers_table  = $request->sub_include_answers_table;

        if($include_answers_table == "1") {

            $sub_questionnaire_id = $subquestionnaire->questionnaire_id;
            $table_no = $request->sub_table_no;
            $table_title = $request->sub_table_title;
            $table_html = $request->sub_table_html;
            $table_js = $request->sub_table_js;

            $tableData = ['sub_questionnaire_id' => $sub_questionnaire_id,
                          'table_no' => $table_no,
                          'table_title' => $table_title,
                          'table_html' => $table_html,
                          'table_js' => $table_js
                        ];
            tap(new QuestionnaireTable($tableData))->save();
        }

        return redirect(SubQuestionnaireController::SUB_SUB_QUESTIONNAIRE_URL.$request->parent_sub_questionnaire_id);
    }

    public function edit($id) {
        
        //TO DO: The Whole Thing

        return redirect(SubQuestionnaireController::SUB_QUESTIONNAIRE_URL);

    }

    public function del(Request $request) {

        $subquestionnaireId = $request->deletesubquestionnaire;
        $questionnaireId = $request->questionnaire_id;

        //TO DO: Make sure request has questionnaire_id
        $subquestionnaire = SubQuestionnaire::find($subquestionnaireId);
        $subquestionnaire->delete();

        return redirect(SubQuestionnaireController::SUB_QUESTIONNAIRE_URL.$questionnaireId);
    }

    public function view($id) {

        $subquestionnaireId = $id;
        $selectedSubQuestion = SubQuestionnaire::find($subquestionnaireId);

        $sub_sub_questionnaires = SubQuestionnaire::where('parent_sub_questionnaire_id',
         '=', $subquestionnaireId)->get();

         //TO DO: Take Care of SUB_SUB_QUESTIONNAIRE_BLADE
        return view(SubQuestionnaireController::SUB_SUB_QUESTIONNAIRE_BLADE,
            ['sub_sub_questionnaires' => $sub_sub_questionnaires,
            'selectedSubQuestion' => $selectedSubQuestion]);
    }
}