<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

use App\Models\User;
use App\Models\UserRole;
use App\Models\Institution;
use Illuminate\Support\Facades\Auth;

class UserController extends Controller
{

    const USERS_BLADE = 'src/users';
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $users = User::all();
        $user_roles = UserRole::all();
        $institutions = Institution::all();

        return view(UserController::USERS_BLADE, ['users' => $users,
         'user_roles' => $user_roles, 'institutions' => $institutions,
          'selectedUser' => null]);
    }

    public function save(Request $request){

        $data = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'user_type' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'msisdn' => ['required', 'numeric', 'min:10']
        ]);

        $data['created_by'] = Auth::user()->user_id;
        $data['institution_id'] = $request->institution_id;
        $data['user_role_id'] = $data['user_type'];
        $data['approved_by'] = Auth::user()->user_id;
        $data['status'] = 1;
    
        $selected = $request->selected_user;
    
        if($selected){

            $updateData = ['name' => $data['name'], 
                            'user_role_id' => $data['user_type'],
                            'msisdn' => $data['msisdn'],
                            'email' => $data['email'],
                            'institution_id' => $data['institution_id']];

            $user = tap(User::where('user_id', $selected)->update($updateData));

        }else {

            $data = $request->validate([
                'name' => ['required', 'string', 'max:255'],
                'user_type' => ['required', 'string', 'max:255'],
                'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
                'password' => ['required', 'string', 'min:8', 'confirmed'],
                'msisdn' => ['required', 'numeric', 'min:10']
            ]);

            $data['created_by'] = Auth::user()->user_id;
            $data['institution_id'] = $request->institution_id;
            $data['user_role_id'] = $data['user_type'];
            $data['approved_by'] = Auth::user()->user_id;
            $data['status'] = 1;
            $data['password'] = Hash::make($data['password']);

            $user = tap(new User($data))->save();
        }
        return redirect('/users');
    }

    public function search(Request $request){

        $keyword = $request->keyword;
        $users = DB::select(Db::raw("select `name`, institution_name,  msisdn, user.status,
             user.user_id, user.institution_id from user left join institution  
            on user.institution_id = institution.institution_id where institution_name
             like '%".$keyword."%' or msisdn like '%".$keyword."%' or 
             email like '%".$keyword."%'  or `name` like '%".$keyword."%'"));

        return json_encode($users);
    }

    public function edit($id) {
        
        $userId = $id;
        $selectedUser = User::find($userId);
        $users = User::all();
        $user_roles = UserRole::all();
        $institutions = Institution::all();

        return view(UserController::USERS_BLADE, 
            ['users' => $users, 'user_roles' => $user_roles, 
            'institutions' =>$institutions, 'selectedUser' => $selectedUser]);
    }

    public function del(Request $request) {

        $userId = $request->deleteuser;
        $user = User::find($userId);
        $user->update(['status' => -1]);
        $users = User::all();
        $user_roles = UserRole::all();
        $institutions = Institution::all();

        return view(UserController::USERS_BLADE, 
            ['users' => $users, 'user_roles' => $user_roles, 
            'institutions' =>$institutions, 'selectedUser' => null]);
    }
}