<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $control_figure_id
 * @property integer $questionnaire_id
 * @property integer $sub_questionnaire_id
 * @property integer $questionnaire_table_id
 * @property integer $created_by
 * @property string $control_figure_name
 * @property int $value
 * @property string $created
 * @property string $modified
 * @property integer $status
 * @property User $user
 * @property Questionnaire $questionnaire
 * @property SubQuestionnaire $subQuestionnaire
 * @property QuestionnaireTable $questionnaireTable
 */
class ControlFigure extends Model
{
    /**
     * The table associated with the model.
     * 
     * @var string
     */
    protected $table = 'control_figure';

    /**
     * The primary key for the model.
     * 
     * @var string
     */
    protected $primaryKey = 'control_figure_id';

    /**
     * The "type" of the auto-incrementing ID.
     * 
     * @var string
     */
    protected $keyType = 'integer';

    public $timestamps = false;

    /**
     * @var array
     */
    protected $fillable = ['questionnaire_id', 'sub_questionnaire_id', 
    'questionnaire_table_id', 'created_by', 'control_figure_name', 'value',
     'created', 'modified', 'status'];

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo('App\Models\User', 'created_by', 'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function questionnaire()
    {
        return $this->belongsTo('App\Models\Questionnaire', null, 'questionnaire_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function subQuestionnaire()
    {
        return $this->belongsTo('App\Models\SubQuestionnaire', null, 'sub_questionnaire_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function questionnaireTable()
    {
        return $this->belongsTo('App\Models\QuestionnaireTable', null, 'questionnaire_table_id');
    }
}
