<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $county_id
 * @property integer $created_by
 * @property string $county_name
 * @property string $county_code
 * @property integer $status
 * @property string $created
 * @property string $modified
 * @property User $user
 * @property Constituency[] $constituencies
 * @property CountyAssembly[] $countyAssemblies
 */
class County extends Model
{
    /**
     * The table associated with the model.
     * 
     * @var string
     */
    protected $table = 'county';

    /**
     * The primary key for the model.
     * 
     * @var string
     */
    protected $primaryKey = 'county_id';

    /**
     * The "type" of the auto-incrementing ID.
     * 
     * @var string
     */
    protected $keyType = 'integer';

    public $timestamps = false;

    /**
     * @var array
     */
    protected $fillable = ['created_by', 'county_name', 'county_code',
     'status', 'created', 'modified'];

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo('App\Models\User', 'created_by', 'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function constituencies()
    {
        return $this->hasMany('App\Models\Constituency', null, 'county_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function countyAssemblies()
    {
        return $this->hasMany('App\Models\CountyAssembly', null, 'county_id');
    }
}
