<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $institution_id
 * @property integer $sub_category_id
 * @property integer $created_by
 * @property string $institution_name
 * @property string $description
 * @property string $created
 * @property string $modified
 * @property integer $status
 * @property User $user
 * @property SubCategory $subCategory
 */
class Institution extends Model
{
    /**
     * The table associated with the model.
     * 
     * @var string
     */
    protected $table = 'institution';

    /**
     * The primary key for the model.
     * 
     * @var string
     */
    protected $primaryKey = 'institution_id';

    /**
     * The "type" of the auto-incrementing ID.
     * 
     * @var string
     */
    protected $keyType = 'integer';

    public $timestamps = false;

    /**
     * @var array
     */
    protected $fillable = ['sub_category_id', 'created_by', 'institution_name',
     'description', 'created', 'modified', 'status'];

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo('App\Models\User', 'created_by', 'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function subCategory()
    {
        return $this->belongsTo('App\Models\SubCategory', 'sub_category_id',
         'sub_category_id');
    }
}
