<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $questionnaire_id
 * @property integer $category_id
 * @property integer $sub_category_id
 * @property integer $questionnaire_part_id
 * @property integer $questionnaire_section_id
 * @property integer $questionnaire_table_id
 * @property integer $created_by
 * @property string $question
 * @property int $question_no
 * @property boolean $needs_upload
 * @property string $checkbox_options
 * @property string $dropdown_options
 * @property string $created
 * @property string $modified
 * @property integer $status
 * @property User $user
 * @property Category $category
 * @property SubCategory $subCategory
 * @property QuestionnairePart $questionnairePart
 * @property QuestionnaireSection $questionnaireSection
 * @property QuestionnaireTable $questionnaireTable
 * @property ControlFigure[] $controlFigures
 * @property QuestionnaireAnswer[] $questionnaireAnswers
 * @property QuestionnaireAnswerDetail[] $questionnaireAnswerDetails
 * @property SubQuestionnaire[] $subQuestionnaires
 */
class Questionnaire extends Model
{
    /**
     * The table associated with the model.
     * 
     * @var string
     */
    protected $table = 'questionnaire';

    /**
     * The primary key for the model.
     * 
     * @var string
     */
    protected $primaryKey = 'questionnaire_id';

    /**
     * The "type" of the auto-incrementing ID.
     * 
     * @var string
     */
    protected $keyType = 'integer';

    public $timestamps = false;

    /**
     * @var array
     */
    protected $fillable = ['category_id', 'sub_category_id', 'questionnaire_part_id',
     'questionnaire_section_id', 'created_by', 'question',
      'question_no', 'feedback_area', 'needs_upload', 'checkbox_options',
       'dropdown_options', 'created',
       'modified', 'status'];

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo('App\Models\User', 'created_by', 'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function category()
    {
        return $this->belongsTo('App\Models\Category', null, 'category_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function subCategory()
    {
        return $this->belongsTo('App\Models\SubCategory', null, 'sub_category_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function questionnairePart()
    {
        return $this->belongsTo('App\Models\QuestionnairePart', 
        'questionnaire_part_id', 'questionnaire_part_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function questionnaireSection()
    {
        return $this->belongsTo('App\Models\QuestionnaireSection',
         'questionnaire_section_id', 'questionnaire_section_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function controlFigures()
    {
        return $this->hasMany('App\Models\ControlFigure', null,
         'questionnaire_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function questionnaireAnswers()
    {
        return $this->hasMany('App\Models\QuestionnaireAnswer', null,
         'questionnaire_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function questionnaireAnswerDetails()
    {
        return $this->hasMany('App\Models\QuestionnaireAnswerDetail', null,
         'questionnaire_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function subQuestionnaires()
    {
        return $this->hasMany('App\Models\SubQuestionnaire', null,
         'questionnaire_id');
    }
}
