<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $questionnaire_answer_id
 * @property integer $questionnaire_id
 * @property integer $answered_by
 * @property integer $approved_by
 * @property integer $created_by
 * @property string $created
 * @property string $modified
 * @property Questionnaire $questionnaire
 * @property User $user
 * @property User $user
 * @property User $user
 * @property QuestionnaireAnswerDetail[] $questionnaireAnswerDetails
 */
class QuestionnaireAnswer extends Model
{
    /**
     * The table associated with the model.
     * 
     * @var string
     */
    protected $table = 'questionnaire_answer';

    /**
     * The primary key for the model.
     * 
     * @var string
     */
    protected $primaryKey = 'questionnaire_answer_id';

    /**
     * The "type" of the auto-incrementing ID.
     * 
     * @var string
     */
    protected $keyType = 'integer';

    public $timestamps = false;

    /**
     * @var array
     */
    protected $fillable = ['questionnaire_id', 'sub_questionnaire_id', 'institution_id',
     'answered_by', 'in_progress', 'submitted_for_review ', 'returned_for_review',
      'review_comments', 'approved_by', 'questionnaire_year', 'created_by', 'created',
       'modified'];

    const USER_MODEL = 'App\Models\User';

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function questionnaire()
    {
        return $this->belongsTo('App\Models\Questionnaire', 'questionnaire_id',
         'questionnaire_id');
    }


    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function institution()
    {
        return $this->belongsTo('App\Models\Institution', 'institution_id',
         'institution_id');
    }


    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function subQuestionnaire()
    {
        return $this->belongsTo('App\Models\SubQuestionnaire',
         'sub_questionnaire_id', 'sub_questionnaire_id');
    }


    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function answeredBy()
    {
        return $this->belongsTo(QuestionnaireAnswer::USER_MODEL, 'answered_by',
         'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function approvedBy()
    {
        return $this->belongsTo(QuestionnaireAnswer::USER_MODEL, 'approved_by',
         'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo('App\Models\User', 'created_by', 'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function questionnaireAnswerDetails()
    {
        return $this->hasMany('App\Models\QuestionnaireAnswerDetail', null,
         'questionnaire_answer_id');
    }
}
