<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $questionnaire_part_id
 * @property integer $created_by
 * @property string $part_name
 * @property integer $status
 * @property string $created
 * @property string $modified
 * @property User $user
 * @property Questionnaire[] $questionnaires
 * @property QuestionnaireSection[] $questionnaireSections
 */
class QuestionnairePart extends Model
{
    /**
     * The table associated with the model.
     * 
     * @var string
     */
    protected $table = 'questionnaire_part';

    /**
     * The primary key for the model.
     * 
     * @var string
     */
    protected $primaryKey = 'questionnaire_part_id';

    /**
     * The "type" of the auto-incrementing ID.
     * 
     * @var string
     */
    protected $keyType = 'integer';

    public $timestamps = false;

    /**
     * @var array
     */
    protected $fillable = ['created_by', 'part_name', 'status',
     'created', 'modified'];

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo('App\Models\User', 'created_by', 'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function questionnaires()
    {
        return $this->hasMany('App\Models\Questionnaire', null,
         'questionnaire_part_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function questionnaireSections()
    {
        return $this->hasMany('App\Models\QuestionnaireSection', null,
         'questionnaire_part_id');
    }
}
