<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $questionnaire_section_id
 * @property integer $questionnaire_part_id
 * @property integer $created_by
 * @property string $section_name
 * @property integer $status
 * @property string $created
 * @property string $modified
 * @property User $user
 * @property QuestionnairePart $questionnairePart
 * @property Questionnaire[] $questionnaires
 */
class QuestionnaireSection extends Model
{
    /**
     * The table associated with the model.
     * 
     * @var string
     */
    protected $table = 'questionnaire_section';

    /**
     * The primary key for the model.
     * 
     * @var string
     */
    protected $primaryKey = 'questionnaire_section_id';

    /**
     * The "type" of the auto-incrementing ID.
     * 
     * @var string
     */
    protected $keyType = 'integer';

    public $timestamps = false;

    /**
     * @var array
     */
    protected $fillable = ['questionnaire_part_id', 'created_by', 'section_name',
     'status', 'created', 'modified'];

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo('App\Models\User', 'created_by', 'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function questionnairePart()
    {
        return $this->belongsTo('App\Models\QuestionnairePart', 'questionnaire_part_id',
         'questionnaire_part_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function questionnaires()
    {
        return $this->hasMany('App\Models\Questionnaire', null,
         'questionnaire_section_id');
    }
}
