<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $sub_questionnaire_id
 * @property integer $questionnaire_id
 * @property integer $parent_sub_questionnaire_id
 * @property integer $created_by
 * @property string $question
 * @property integer $feedback_area
 * @property boolean $needs_upload
 * @property string $checkbox_options
 * @property string $dropdown_options
 * @property string $created
 * @property string $modified
 * @property integer $status
 * @property User $user
 * @property Questionnaire $questionnaire
 * @property QuestionnaireTable $questionnaireTable
 * @property SubQuestionnaire $subQuestionnaire
 * @property ControlFigure[] $controlFigures
 * @property QuestionnaireAnswerDetail[] $questionnaireAnswerDetails
 */
class SubQuestionnaire extends Model
{
    /**
     * The table associated with the model.
     * 
     * @var string
     */
    protected $table = 'sub_questionnaire';

    /**
     * The primary key for the model.
     * 
     * @var string
     */
    protected $primaryKey = 'sub_questionnaire_id';

    /**
     * The "type" of the auto-incrementing ID.
     * 
     * @var string
     */
    protected $keyType = 'integer';

    public $timestamps = false;

    /**
     * @var array
     */
    protected $fillable = ['questionnaire_id', 'parent_sub_questionnaire_id',
         'created_by', 'sub_question', 'feedback_area', 'sub_question_no', 'needs_upload',
          'checkbox_options', 'dropdown_options', 'created', 'modified', 'status'];

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo('App\Models\User', 'created_by', 'user_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function questionnaire()
    {
        return $this->belongsTo('App\Models\Questionnaire', null, 'questionnaire_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function subQuestionnaire()
    {
        return $this->belongsTo('App\Models\SubQuestionnaire', 
        'parent_sub_questionnaire_id', 'sub_questionnaire_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function controlFigures()
    {
        return $this->hasMany('App\Models\ControlFigure', 'sub_questionnaire_id', 
        'sub_questionnaire_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function questionnaireAnswerDetails()
    {
        return $this->hasMany('App\Models\QuestionnaireAnswerDetail', 
        'sub_questionnaire_id', 'sub_questionnaire_id');
    }
}
