@extends('layouts.app')
@section('content')

<div class="row">
    <div class="col-sm-3">
        @include('side_menu')
    </div>
    <div class="col-sm-9">
        <div class="row">
            <div class="col-sm-12 add-container">
                <form action="/countyassembly/save" method="post" class="add-form">
                    <div class="container">
                        <div class="row">
                            @csrf
                            @if ($errors->any())
                            <div class="alert alert-danger" role="alert">
                                Please fix the following errors
                            </div>
                            @endif
                            @if($selectedCountyassembly != null)
                            <input type="hidden" id="selected_countyassembly" name="selected_countyassembly" value="{{$selectedCountyassembly->county_assembly_id}}" />
                            @endif
                            <div class="col-sm-9">
                                <div class="form-group">
                                    <label for="county_assembly_name">County Assembly Name</label>
                                    <input type="text" class="form-control @error('county_assembly_name') is-invalid @enderror" id="county_assembly_name" name="county_assembly_name" placeholder="Name" value="@if($selectedCountyassembly != null){{$selectedCountyassembly->county_assembly_name}}@else{{ old('county_assembly_name') }}@endif">
                                    @error('county_assembly_name')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-9">
                                <div class="form-group">
                                    <label for="county_assembly_code">County Assembly Code</label>
                                    <input type="text" class="form-control @error('county_assembly_code') is-invalid @enderror" id="county_assembly_code" name="county_assembly_code" placeholder="County Assembly Code" value="@if($selectedCountyassembly != null){{$selectedCountyassembly->county_assembly_code}}@else{{ old('county_assembly_code') }}@endif">
                                    @error('countyassembly_code')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-9">
                                <div class="form-group">
                                    <label for="county">County</label>
                                    <select class="form-control @error('county') is-invalid @enderror" id="county_id" name="county_id">
                                        <option value="">Select County</option>
                                        @foreach($counties as $county)
                                        @if($selectedCountyassembly != null)
                                            <option @if($selectedCountyassembly->county_id == $county->county_id) selected @endif value="{{$county->county_id}}">{{$county->county_name}}</option>
                                        @else
                                            <option value="{{$county->county_id}}">{{$county->county_name}}</option>
                                        @endif
                                        @endforeach
                                    </select>
                                    @error('title')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-9">
                                <button type="submit" class="btn btn-primary bt-margin">Save</button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
            <div class="container">
                <div class="row search-mg">
                    <div class="col-md-12 search-col">
                        <button class="btn float-right search-bt" onclick="searchCountyAssemblies()">Search</button>
                        <input type="text" class="form-control float-right search-txt" id="search-countyassembly" name="search-countyassembly" placeholder="Search" />
                    </div>
                </div>
                <div class="row t-header">
                    <div class="col-3">County Assembly Code</div>
                    <div class="col-4">County Assembly Name</div>
                    <div class="col-3">County</div>
                    <div class="col-2"></div>
                </div>
                <div id="countyassemblies-data">
                    @foreach ($countyassemblies as $countyassembly)
                    <div class="row t-content">
                        <div class="col-3">
                            {{ $countyassembly->county_assembly_code }}
                        </div>
                        <div class="col-4">
                            {{ $countyassembly->county_assembly_name }}
                        </div>
                        <div class="col-3">
                            {{ $countyassembly->county->county_name }}
                        </div>
                        <div class="col-2 edit-butts">
                            <span>
                                <a href="/countyassembly/edit/{{$countyassembly->county_assembly_id}}">
                                    <img src="/images/edit.png" width="15px" alt="Edit" />
                                </a>
                                <button rel="{{$countyassembly->county_assembly_id}}" class="btn delcountyassembly" data-toggle="modal" data-target="#countyassembliesModal">
                                    <img src="/images/delete.png" width="15px" alt="Delete" />
                                </button>
                            </span>
                        </div>
                    </div>
                    @endforeach
                </div>
            </div>
        </div>
    </div>

    <!-- Modal -->
    <div class="modal fade" id="countyassembliesModal" tabindex="-1" role="dialog" aria-labelledby="countyassembliesModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="countyassembliesModalLabel">Confirm Delete</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    Are you sure you would like to delete the selected county assembly?
                </div>
                <div class="modal-footer">
                    <div class="row" style="width:100%">
                        <div class="col-8">
                            <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancel</button>
                        </div>
                        <div class="col-4">
                            <form action="/countyassembly/del" method="post">
                                @csrf
                                <input type="hidden" id="del-countyassembly" name="deletecountyassembly" />
                                <button type="submit" class="btn btn-primary">Confirm</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    @endsection